translate.tools.poterminology

Package translate :: Package tools :: Module poterminology |
[hide private]
[frames] | no frames]

# Module poterminology

source code

reads a set of .po or .pot files to produce a pootle-terminology.pot

See: http://translate.sourceforge.net/wiki/toolkit/poterminology for examples and usage instructions

Classes | [hide private]
| TerminologyOptionParser a specialized Option Parser for the terminology tool...

Functions | [hide private]
fold_case_option(option, opt_str, value, parser) | source code
preserve_case_option(option, opt_str, value, parser) | source code
parse_stopword_file(option, opt_str, value, parser) | source code
main() | source code

Imports: lang_factory, optrecurse, po, factory, file_discovery, os, re, sys